.. _pecan_util:

:mod:`pecan.util` -- Pecan Utils
================================

The :mod:`pecan.util` module includes utility functions for Pecan.

.. automodule:: pecan.util
  :members:
  :show-inheritance: